## ---------------------------
##
## Script name: Load data for the model
##
## Purpose of script: Master script to load data for the gadget model
##
## ---------------------------

## Source or list custom functions used within the script

## ---------------------------

##########################
## Modify reload_data ####

remake_init_sigmas <- reload_data

if(reset_model | !(exists("optim_fit") | file.exists(file.path(base_dir, "optim/Optimized TMB model fit.rda")))) {
  remake_init_sigmas <- FALSE
}

## Life history parameters ####

source("2-1 life history.R")

## Survey indices ####

### Download data
#### Updates the survey indices but requires IMR server connection.
#### Modify server_path to fit your system

if(reload_data) {
  server_path <- "/Volumes/Felles/Dyphavsarter/Arter/Blakveite/GADGET/Stox/GHL"
  
  if(!dir.exists(server_path)) {
    message("Cannot connect to IMR servers. Loading data from the data folder
            instead of download from the servers.")
    
    load("data/EggaN survey index data.rda")
    load("data/EggaS survey index data.rda")
    load("data/Ecosystem survey index data.rda")
    
  } else {
    source("2-2-1 download survey index data.R")
  }
} else if(reset_model) {
  load("data/EggaN survey index data.rda")
  load("data/EggaS survey index data.rda")
  load("data/Ecosystem survey index data.rda")
}

if(reset_model) {
  message("Processing survey indices...")
  source("2-2-2 survey indices.R")
} else {
  load(file.path(base_dir, "data/Survey indices to Gadget.rda"))
}

## Length, sex and maturity distributions ####

if(reload_data) {
  
  # Requires local setup of BioticExplorerServer. Ask Mikko for details.
  
  ## Load packages
  
  packages <- c("MonetDB.R", "DBI", "ggOceanMaps", "sf")
  
  # Install packages not yet installed
  installed_packages <- packages %in% rownames(installed.packages())
  if (any(installed_packages == FALSE)) {
    install.packages(packages[!installed_packages])
  }
  
  # Packages loading
  invisible(lapply(packages, library, character.only = TRUE))
  
  rm(packages)
  
  ## Test BioticExplorerServer connection
  
  if(exists("con_db")) {
    DBI::dbDisconnect(con_db)
  }
  
  con_db <- suppressWarnings(try(DBI::dbConnect(
    MonetDB.R::MonetDB(), host="localhost", dbname="bioticexplorer",
    user="monetdb", password="monetdb"),
    silent = TRUE))
  
  if(inherits(con_db, "try-error")) {
    
    message(strwrap("Cannot connect to BioticExplorerServer. Make sure that the required
    software is installed and the database is running:
    system('monetdbd start ~/Desktop/my-dbfarm'). Loading distribution data
    from the data folder instead of reloading."))
    
  } else {
    message("Database connection successful. Acquiring data.")
    source("2-3-1 download distribution data.R")
  }
}

if(reset_model) {
  message("Processing catch distributions...")
  source("2-3-2 catch distributions.R")
} else {
  load(file.path(base_dir, "data/Catch distributions to Gadget.rda"))
}

## Catches ####

if(reload_data) {
  
  message("Catch data")
  
  connection_test <- try(readLines("http://tomcat7.imr.no:8080/apis/nmdapi/reference/v2/dataset/equipment?version=2.0", n=1))
  connection_test <- !inherits(connection_test, "try-error")
  
  if(connection_test) {
    message("Catch database connection successful. Acquiring data.")
    source("2-4-1 download catch data.R")
  } else {
    message(strwrap("Cannot connect to the IMR API. Make sure that you are
    connected to IMR intranet. Loading catch data from the data folder instead
                    of reloading."))
    
  }
}

if(reset_model) {
  message("Processing catches...")
  source("2-4-2 catches.R")
} else {
  load(file.path(base_dir, "data/Catches to Gadget.rda"))
}