## ---------------------------
##
## Script name: Load life history data
##
## Purpose of script: Loads initial sigmas that are the only life history data
##                    not added to parameters automatically. Uses previous models
##                    to estimate these. See the report for estimation of life
##                    history parameters.
##
## ---------------------------

## Source or list custom functions used within the script

## ---------------------------

if(reset_model) {
  if(remake_init_sigmas) {
    
    if(!exists("optim_fit")) load(file.path(base_dir, "optim/Optimized TMB model fit.rda"))
    
    # Read initial sigmas
    optim_fit$stock.std %>%
      dplyr::filter(.data$number > 0) %>%
      dplyr::arrange(.data$year, .data$step, .data$stock, .data$age) %>%
      dplyr::group_by(.data$stock, .data$age) %>%
      dplyr::summarise(
        mean = mean(.data$mean_length, na.rm = TRUE),
        mean_sd = mean(.data$stddev_length, na.rm = TRUE),
        .groups = "drop"
      ) %>%
      rename(ms = mean_sd, ml = mean) %>%
      dplyr::select(age, stock, ms, ml) %>%
      write_csv("data/Initial ldist data.csv")
    
  } else {
    ### Acquired from iterated fit object 2023-02-08
    init_sigma <- readr::read_csv("data/Initial ldist data.csv",
                                  col_types = cols())
  }
  
  save(init_sigma, file = file.path(base_dir, "data/Initial stock parameters.rda"))
  
} else {
  load(file.path(base_dir, "data/Initial stock parameters.rda"))
}
