## ---------------------------
##
## Script name: Download survey index data into the data folder
##
## ---------------------------

## Source or list custom functions used within the script

## ---------------------------

################################################
## Juvenile index from the Ecosystem Survey ####

base_path <- file.path(server_path, "Ecosystem")

folders <- list.dirs(path = base_path, full.names = F, recursive = F)

# k <- folders[length(folders)]
BESS <- pbapply::pblapply(folders, function(k) {

  message(k)
  Y <- as.integer(gsub("\\D", "", k))

  # Read data ####

  dt <- readr::read_delim(
    file.path(base_path, k,
              "output/baseline/ImputeSuperindividuals2/SuperIndividualsData.txt"),
    delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
    filter(!is.na(Abundance) | !is.na(Biomass))

  # n_empty_strata <- sum(is.na(dt$Abundance))
  # empty_strata <- dt$Stratum[which(is.na(dt$Abundance))]

  dt$IndividualSex[is.na(dt$IndividualSex)] <- "U"

  ## Abundances

  tmp <- dt[!is.na(dt$Abundance),]

  abundance_station_length <- tmp %>%
    group_by(Stratum, HaulKey, Longitude, Latitude, BottomDepth, IndividualSex, IndividualTotalLength) %>%
    summarise(Abundance = sum(Abundance)) %>%
    add_column(year = Y, .before = 1)

  tmp <- dt[!is.na(dt$Biomass),]

  biomass_station_length <- tmp %>%
    group_by(Stratum, HaulKey, Longitude, Latitude, BottomDepth, IndividualSex, IndividualTotalLength) %>%
    summarise(Biomass = sum(Biomass)/1e3) %>% # StoX uses grams -> to kg
    add_column(year = Y, .before = 1)

  station_length <- suppressMessages({
    full_join(abundance_station_length, biomass_station_length)
    })

  # Bootstrapped values ####
  if(file.exists(file.path(base_path, k, "output/report/ReportBootstrap_Abundance_Length_Stratum/ReportBootstrapData.txt"))) {
    bs_abundance <- readr::read_delim(
      file.path(base_path, k, "output/report/ReportBootstrap_Abundance_Length_Stratum/ReportBootstrapData.txt"),
      delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
      filter(!is.na(IndividualTotalLength)) %>%
      add_column(year = Y, .before = 1)
  } else {
    bs_abundance <- NULL
  }

  if(file.exists(file.path(base_path, k, "output/report/ReportBootstrap_Biomass_Length_Stratum/ReportBootstrapData.txt"))) {
    bs_biomass <- readr::read_delim(
      file.path(base_path, k, "output/report/ReportBootstrap_Biomass_Length_Stratum/ReportBootstrapData.txt"),
      delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
      filter(!is.na(IndividualTotalLength)) %>%
      mutate_at(vars(contains("Biomass")), ~./1e3) %>%
      add_column(year = Y, .before = 1) # values returned in kg
  } else {
    bs_biomass <- NULL
  }

  # Return

  list(station_length = station_length, bs_abundance = bs_abundance, bs_biomass = bs_biomass)
  # , n_empty_strata = n_empty_strata, empty_strata = empty_strata)
})

names(BESS) <- as.integer(gsub("\\D", "", folders))

## Save

save(BESS, file = "data/Ecosystem survey index data.rda", compress = "xz")

#############
## EggaN ####

base_path <- file.path(server_path, "EggaN")

folders <- list.dirs(path = base_path, full.names = F, recursive = F)

# k <- folders[8]
EggaN <- pbapply::pblapply(folders, function(k) {

  message(k)
  Y <- as.integer(gsub("\\D", "", k))

  # ####

  dt <- read_delim(
    file.path(base_path, k,
              "output/baseline/ImputeSuperIndividuals_weight_Final/SuperIndividualsData.txt"),
    delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
    filter(!is.na(Abundance) | !is.na(Biomass))

  dt$IndividualSex[is.na(dt$IndividualSex)] <- "U"

  ## Abundances

  tmp <- dt[!is.na(dt$Abundance),]

  abundance_station_length <- tmp %>%
    group_by(Stratum, HaulKey, Longitude, Latitude, BottomDepth, IndividualSex, IndividualAge, IndividualTotalLength) %>%
    summarise(Abundance = sum(Abundance)) %>%
    add_column(year = Y, .before = 1)

  ## Biomasses (values returned in kilograms)

  tmp <- dt[!is.na(dt$Biomass),]

  biomass_station_length <- tmp %>%
    group_by(Stratum, HaulKey, Longitude, Latitude, BottomDepth, IndividualSex, IndividualAge, IndividualTotalLength) %>%
    summarise(Biomass = sum(Biomass)/1e3) %>%  # StoX uses grams -> to kg
    add_column(year = Y, .before = 1)

  station_length <- suppressMessages({full_join(abundance_station_length, biomass_station_length)})

  # Bootstrapped values ####
  if(file.exists(file.path(base_path, k, "output/report/ReportBootstrap_Abundance/ReportBootstrapData.txt"))) {
    bs_abundance_year <- read_delim(
      file.path(base_path, k, "output/report/ReportBootstrap_Abundance/ReportBootstrapData.txt"),
      delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
      add_column(year = Y, .before = 1)
  } else {
    bs_abundance_year <- NULL
  }

  if(file.exists(file.path(base_path, k, "output/report/ReportBootstrap_Biomass/ReportBootstrapData.txt"))) {
    bs_biomass_year <- read_delim(
      file.path(base_path, k, "output/report/ReportBootstrap_Biomass/ReportBootstrapData.txt"),
      delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
      mutate_at(vars(contains("Biomass")), ~./1e3) %>%
      add_column(year = Y, .before = 1) # values returned in kg
  } else {
    bs_biomass_year <- NULL
  }
  # Return

  list(station_length = station_length, bs_abundance_year = bs_abundance_year, bs_biomass_year = bs_biomass_year)
})

names(EggaN) <- as.integer(gsub("\\D", "", folders))

## Save

save(EggaN, file = "data/EggaN survey index data.rda", compress = "xz")

#############
## EggaS ####

base_path <- file.path(server_path, "EggaS")

folders <- list.dirs(path = base_path, full.names = F, recursive = F)

# k <- folders[1]
EggaS <- pbapply::pblapply(folders, function(k) {

  message(k)
  Y <- as.integer(gsub("\\D", "", k))

  # ####

  dt <- read_delim(
    file.path(base_path, k,
              "output/baseline/ImputeSuperIndividuals_weight_Final/SuperIndividualsData.txt"),
    delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
    filter(!is.na(Abundance) | !is.na(Biomass))

  dt$IndividualSex[is.na(dt$IndividualSex)] <- "U"

  ## Abundances

  tmp <- dt[!is.na(dt$Abundance),]

  abundance_station_length <- tmp %>%
    group_by(Stratum, HaulKey, Longitude, Latitude, BottomDepth, IndividualSex, IndividualAge, IndividualTotalLength) %>%
    summarise(Abundance = sum(Abundance)) %>%
    add_column(year = Y, .before = 1)

  ## Biomasses (values returned in kilograms)

  tmp <- dt[!is.na(dt$Biomass),]

  biomass_station_length <- tmp %>%
    group_by(Stratum, HaulKey, Longitude, Latitude, BottomDepth, IndividualSex, IndividualAge, IndividualTotalLength) %>%
    summarise(Biomass = sum(Biomass)/1e3) %>%  # StoX uses grams -> to kg
    add_column(year = Y, .before = 1)

  station_length <- suppressMessages({full_join(abundance_station_length, biomass_station_length)})

  # Bootstrapped values ####
  if(file.exists(file.path(base_path, k, "output/report/ReportBootstrap_Abundance/ReportBootstrapData.txt"))) {
    bs_abundance_year <- read_delim(
      file.path(base_path, k, "output/report/ReportBootstrap_Abundance/ReportBootstrapData.txt"),
      delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
      add_column(year = Y, .before = 1)
  } else {
    bs_abundance_year <- NULL
  }

  if(file.exists(file.path(base_path, k, "output/report/ReportBootstrap_Biomass/ReportBootstrapData.txt"))) {
    bs_biomass_year <- read_delim(
      file.path(base_path, k, "output/report/ReportBootstrap_Biomass/ReportBootstrapData.txt"),
      delim = "\t", show_col_types = FALSE, progress = FALSE) %>%
      add_column(year = Y, .before = 1) # values returned in grams
  } else {
    bs_biomass_year <- NULL
  }
  # Return

  list(station_length = station_length, bs_abundance_year = bs_abundance_year, bs_biomass_year = bs_biomass_year)
})

names(EggaS) <- as.integer(gsub("\\D", "", folders))

## Save

save(EggaS, file = "data/EggaS survey index data.rda", compress = "xz")

