## ---------------------------
##
## Script name: Download catches into the data folder
##
## ---------------------------

## Load packages ####

message("Setting up...")

packages <- c("RstoxUtils")

### Install packages not yet installed

installed_packages <- packages %in% rownames(installed.packages())

if("RstoxUtils" %in% packages[!installed_packages]) {
  remotes::install_github("MikkoVihtakari/RstoxUtils", upgrade = "never")
}

### Load the packages to work space

invisible(lapply(packages, library, character.only = TRUE))

rm(packages, installed_packages)

## Gear list ####

source("R/gears2MFDB.R")
gearList <- try(gears2MFDB("data/Kodeliste-landing-20210702.xlsx"), silent = TRUE)

if(any(class(gearList) == "try-error")) {
  load("data/gearList.rda")
} else {
  save(gearList, file = "data/gearList.rda", compress = "xz")
}

## Norwegian catches ####

connection_test <- try(readLines("http://tomcat7.imr.no:8080/apis/nmdapi/reference/v2/dataset/equipment?version=2.0", n=1))
connection_test <- !inherits(connection_test, "try-error")

if(connection_test & FALSE) { # turn the switch on for API download. It takes 10-15 min
  message("Downloading Norwegian catches. This takes 10-15 min...")
  lnd <- RstoxUtils::downloadLandings("Blåkveite")
  message("Download finished. Saving the data...")
  save(lnd, file = paste0("data/", as.Date(Sys.time()), " NMD catches.rda"), compress = "xz")
} else {
  load("data/2024-01-23 NMD catches.rda")
}

message("Processing Norwegian catches...")

x <- lnd$Produkt[, c("Fangstår", "SisteFangstdato", "Redskap_kode",
                     "Hovedområde_kode", "Lokasjon_kode", "Fartøynasjonalitet_kode",
                     "Rundvekt"),
                 with = FALSE]
names(x) <- c("year", "date", "gear_id", "main_area", "sub_area", "nation", "mass")
x$date <- as.Date(x$date, format = "%d.%m.%Y")
x <- x %>%
  add_column(month = lubridate::month(.$date), .before = "date") %>%
  mutate_at(vars(main_area, sub_area), as.integer)
x <- x[!is.na(x$mass) & x$mass > 0,]

### Catches 1977-2004 ####

y <- RstoxUtils::readSluttseddelXLS(
  species = "Blåkveite",
  dataDir = "../../Data/Landings data/sluttseddel_xls_ferdige_År/")
y <- y[y$year < 2005,]

y <- y %>%
  select(-ices_area, -gear_category, -gear) %>%
  add_column(date = NA, .before = "main_area") %>%
  add_column(nation = "NOR", .before = "mass") %>%
  mutate_at(vars(main_area), function(x) as.integer(as.character(x)))

### Merge ####

catchIMR <- rbind(as_tibble(x), as_tibble(y)) %>%
  arrange(year, month, main_area, sub_area, gear_id) %>%
  filter(main_area %in% MainAreaFilter) %>%
  mutate(gear_cat = substr(gear_id, 1, 1),
         gear = recode(gear_id, !!!setNames(gearList$gearcategory, gearList$code))) %>%
  mutate_at(vars(nation), factor)

### Save ####

saveRDS(catchIMR, file = "data/Catches from IMR database.rds", compress = "xz")

