## Helper functions copied from the mfdb package

# From: https://github.com/gadget-framework/mfdb/blob/fe1bd410d1edbda0e995da1e8f53b9cdbaf6041c/R/mfdb_helpers.R#L14
# Combine multiple result tables, preserving grouping
mfdb_concatenate_results <- function (...) {
  combined <- rbind(...)
  for (column in names(combined)) {
    x <- lapply(list(...), function (df) attr(df, column))  # Extract attribute list for each df
    x <- do.call(c, x)  # Concatenate the list of attribute lists together
    x <- x[!duplicated(names(x))]  # Strip duplicates, set it against the new df
    attr(combined, column) <- x
  }
  return(combined)
}

# From: https://github.com/gadget-framework/mfdb/blob/fe1bd410d1edbda0e995da1e8f53b9cdbaf6041c/R/mfdb_aggregate_interval.R#L4

mfdb_interval <- function (prefix, vect, open_ended = FALSE) {
  if (length(vect) < 2) {
    stop("vect must at least be 2 items long (min & max)")
  }

  # Convert old T/F form into a list of upper/lower
  if (identical(TRUE, open_ended)) {
    open_ended = c('upper')
  } else if (identical(FALSE, open_ended)) {
    open_ended = c()
  }

  return(structure(vect,
                   names = paste0(prefix, vect),
                   open_ended = open_ended,
                   class = c("mfdb_interval", "mfdb_aggregate")))
}

# From: https://github.com/gadget-framework/mfdb/blob/fe1bd410d1edbda0e995da1e8f53b9cdbaf6041c/R/mfdb_aggregate_group.R#L5

mfdb_group <- function (...) {
  group <- structure(list(...),
                     table_name = paste(
                       "temp",
                       paste0(sample(letters, 5, replace = TRUE), collapse=""),
                       sep = "_"),
                     class = c("mfdb_group", "mfdb_aggregate"))

  invisible(group)
}

mfdb_timestep_yearly <- mfdb_group('1' = 1:12)
mfdb_timestep_biannually <- mfdb_group('1' = 1:6, '2' = 7:12)
mfdb_timestep_quarterly <- mfdb_group('1' = 1:3, '2' = 4:6, '3' = 7:9, '4' = 10:12)
