if (basename(getwd()) == "docs") setwd(normalizePath(".."))

## Source run first
source("0 run first.R")

## Custom functions

source("R/figure_functions.R")
source("R/make_table.R") # loads knitr, kableExtra and flextable

## Custom definitions

rp_cols <- c("MSY" = "#6CA67A", "HRmsy" = "#82C893", "Bpa" = "#056A89", "HRpa" = "#449BCF", "Blim" = "#D44F56", "HRlim" = "#FF5F68")
substock_cols <- c("ghl_female_imm" = "tomato1", "ghl_female_mat" = "tomato4",
                   "ghl_male_imm" = "dodgerblue1", "ghl_male_mat" = "dodgerblue4")

### ggplot theme

theme_cust <- theme_classic(base_size = 14) %+replace%
  theme(strip.background = element_blank(),
        panel.background = element_blank(),
        plot.background = element_blank(),
        legend.background = element_blank(),
        legend.box.background = element_blank(),
        plot.margin = margin(c(5.5, 10, 5.5, 5.5)))

theme_set(theme_cust) # Set default theme globally for the entire project

## Data

base_dir <- "latest_model"
fig_dir <- file.path(base_dir, "figures")

load(file.path("2023_model", "optim", "Optimized TMB model fit.rda"))
last_years_model <- optim_fit

load(
  file.path(
    "../../Articles/Ghl survey index/ghl-index-gadget/latest_model",
    "optim",
    "Optimized TMB model fit.rda")
)
experimental_model <- optim_fit

load(file.path("2024_model_dome", "optim", "Optimized TMB model fit.rda"))
dome_model <- optim_fit

load(file.path(base_dir, "optim", "Optimized TMB model fit.rda"))
fit <- optim_fit
fit$params$value <- unlist(fit$params$value)

### Dome-shaped selectivity model reference points ####

load(
  file.path("2024_model_dome", "long_term_projections",
            "reference_point_table.rda")
)

load(
  file.path("2024_model_dome", "short_term_projections",
            "short_term_projection_tables.Rdata")
)

dome_blim <- rp_tab %>% filter(rp == "Blim") %>% pull(Value) %>% unname()
dome_msy <- rp_tab %>% filter(rp == "MSY") %>% pull(Value) %>% unname()
dome_hrmsy <- rp_tab %>% filter(rp == "HR(bar)msy") %>% pull(Value) %>% unname()
dome_tac <- next_year_tab %>% filter(Basis == "HRmsy") %>% pull(Catch) %>% as.numeric()
dome_nopre_tac <- next_year_tab %>% filter(Basis == "HRmsy no advice rule") %>% pull(Catch) %>% as.numeric()


### Experimental model reference points ####

load(
  file.path(
    "../../Articles/Ghl survey index/ghl-index-gadget/latest_model",
    "long_term_projections",
    "reference_point_table.rda")
)

load(
  file.path(
    "../../Articles/Ghl survey index/ghl-index-gadget/latest_model",
    "short_term_projections",
    "short_term_projection_tables.Rdata")
)

experimental_blim <- rp_tab %>% filter(rp == "Blim") %>% pull(Value) %>% unname()
experimental_msy <- rp_tab %>% filter(rp == "MSY") %>% pull(Value) %>% unname()
experimental_hrmsy <- rp_tab %>% filter(rp == "HR(bar)msy") %>%
  pull(Value) %>% unname()
experimental_tac <- next_year_tab %>% filter(Basis == "HRmsy") %>% pull(Catch) %>% as.numeric()
experimental_nopre_tac <- next_year_tab %>% filter(Basis == "HRmsy no advice rule") %>% pull(Catch) %>% as.numeric()

### Model data ####

# load(file.path(base_dir, "data", "Model and stock parameters.rda"))
# load(file.path(base_dir, "jitter", "jitter_fit.rda"))
# load(file.path(base_dir, "jitter", "jitpar_out.Rdata"))
# load(file.path(base_dir, "retro", "Retro parameters and fit.rda"))
# load(file.path(base_dir, "leaveout", "Leaveout fit.rda"))
# retro_fit <- lapply(retro_list, function(k) k$fit)

### Current model reference points

load(file.path(base_dir, "long_term_projections", "reference_point_table.rda"))
load(file.path(base_dir, "short_term_projections", "short_term_projection_tables.Rdata"))
load(file.path(base_dir, "short_term_projections", "short_term_projection_fit_objects.Rdata"))

advice_year <- basis_tab %>% filter(grepl("Expected catch", Variable)) %>% pull(Variable) %>% gsub("Expected catch ", "", .) %>% gsub("\\(|\\)", "", .) %>% as.integer()
next_year <- next_year_tab %>% filter(grepl("Advice basis", Basis)) %>% pull(Basis) %>% gsub("Advice basis for ", "", .) %>% as.integer()
the_year_after <- last_year_tab %>% filter(grepl("Advice", Basis)) %>% pull(Basis) %>% gsub("Advice basis for ", "", .) %>% as.integer()
last_catch <- plot_catch(fit, type = "total", return_data = TRUE) %>% filter(year == max(year))
last_catch <- setNames(last_catch$value, last_catch$year)

current_blim <- rp_tab %>% filter(rp == "Blim") %>% pull(Value) %>% unname()
current_msy <- rp_tab %>% filter(rp == "MSY") %>% pull(Value) %>% unname()
current_hrmsy <- rp_tab %>% filter(rp == "HR(bar)msy") %>%
  pull(Value) %>% unname()
current_tac <- next_year_tab %>% filter(Basis == "HRmsy") %>% pull(Catch) %>% as.numeric()
current_nopre_tac <- next_year_tab %>% filter(Basis == "HRmsy no advice rule") %>% pull(Catch) %>% as.numeric()

#### Reference points from the advice sheet: https://www.hi.no/hi/nettrapporter/imr-pinro-en-2023-6
official_blim <- 33.391
official_msy <- 19.142
official_bpa <- 46.767
official_hrmsy <- 0.139

library(xkcd)
library(extrafont)

## ####

tmp <- plot_biomass(proj_msy_fit, stocks = "ghl_female_mat", return_data = TRUE) %>%
  dplyr::select(year, value)

tmp %>%
  ggplot(ggplot2::aes(.data$year, .data$value)) +
  geom_line(
    data =
      tibble(rp = c("Bpa", "Blim"),
                  Value = c(official_bpa, official_blim)) %>%
      expand_grid(x = 1980:2024),
    aes(y = Value, x = x, color = rp), position = position_jitter(h = 0.1)
    ) +
  ggplot2::geom_line(position="jitter", size = 3, color = "white") +
  ggplot2::geom_line(position="jitter", size = 1) +
  scale_x_continuous(limits = c(1980,2025)) +
  # coord_cartesian(xlim = c(1980,2024)) +
  scale_color_manual(values = rp_cols) +
  # theme_void() +
  theme(legend.position = "none") +
  theme(text = element_text(size = 16, family = "xkcd")) +
  xkcdaxis(xrange = c(1980,2025), yrange = c(min(tmp$value), max(tmp$value)))

## ####

